==> gwt-material-addins-2.0-rc6.jar: gwt/material/design/addins/client/splitpanel/MaterialSplitPanel.java <==
/*
 * #%L
 * GwtMaterial
 * %%
 * Copyright (C) 2015 - 2017 GwtMaterialDesign
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */
package gwt.material.design.addins.client.splitpanel;

import com.google.gwt.dom.client.Document;
import com.google.gwt.dom.client.Element;
import gwt.material.design.addins.client.MaterialAddins;
import gwt.material.design.addins.client.splitpanel.constants.Dock;
import gwt.material.design.addins.client.splitpanel.js.JsSplitPanel;
import gwt.material.design.addins.client.splitpanel.js.JsSplitPanelOptions;
import gwt.material.design.client.MaterialDesignBase;
import gwt.material.design.client.base.MaterialWidget;
import gwt.material.design.client.constants.Axis;

import static gwt.material.design.addins.client.splitpanel.js.JsSplitPanel.$;

//@formatter:off

/**
 * A high performance content splitter compatible with touch events
 * <p>
 * <h3>XML Namespace Declaration</h3>
 * <pre>
 * {@code
 * xmlns:ma='urn:import:gwt.material.design.addins.client'
 * }
 * </pre>
 * <p>
 * <h3>UiBinder Usage:</h3>
 * <pre>
 * {@code
 *   <ma:splitpanel.MaterialSplitPanel height="500px">
 *       <m:MaterialPanel grid="l6 m6 s6" backgroundColor="grey lighten-2">
 *           <m:MaterialTitle textAlign="CENTER" title="Left Zone" description="Content must be added here"/>
 *       </m:MaterialPanel>
 *       <m:MaterialPanel grid="l6 m6 s6" backgroundColor="grey lighten-3">
 *           <m:MaterialTitle textAlign="CENTER" title="Right Zone" description="Content must be added here"/>
 *       </m:MaterialPanel>
 *   </ma:splitpanel.MaterialSplitPanel>
 * }
 * </pre>
 *
 * @author kevzlou7979
 * @see <a href="http://gwtmaterialdesign.github.io/gwt-material-demo/#splitpanel">Split Panel</a>
 * @see <a href="https://material.io/guidelines/layout/split-screen.html#split-screen-usage">Material Design Specification</a>
 */
//@formatter:on
public class MaterialSplitPanel extends MaterialWidget {

    static {
        if (MaterialAddins.isDebug()) {
            MaterialDesignBase.injectJs(MaterialSplitPanelDebugClientBundle.INSTANCE.splitPanelDebugJs());
            MaterialDesignBase.injectCss(MaterialSplitPanelDebugClientBundle.INSTANCE.splitPanelDebugCss());
        } else {
            MaterialDesignBase.injectDebugJs(MaterialSplitPanelClientBundle.INSTANCE.splitPanelJs());
            MaterialDesignBase.injectCss(MaterialSplitPanelClientBundle.INSTANCE.splitPanelCss());
        }
    }

    private double leftMax;
    private double leftMin;
    private double rightMax;
    private double rightMin;
    private double topMin;
    private double topMax;
    private double bottomMin;
    private double bottomMax;
    private double barPosition = 50;
    private double thickness = 8;
    private Dock dock = Dock.LEFT;
    private Axis axis = Axis.HORIZONTAL;
    private boolean initialized;
    private JsSplitPanel splitted;

    public MaterialSplitPanel() {
        super(Document.get().createDivElement());
    }

    @Override
    protected void onUnload() {}

    /**
     * Initialize the splitter component.
     */
    @Override
    protected void initialize() {
        splitted = $(getElement());
        if (splitted.get(0) != null) {
            JsSplitPanelOptions options = new JsSplitPanelOptions();
            options.barPosition = getBarPosition();
            options.thickness = getThickness() + "px";
            options.rightMax = getRightMax();
            options.rightMin = getRightMin();
            options.leftMax = getLeftMax();
            options.leftMin = getLeftMin();
            options.topMax = getTopMax();
            options.topMin = getTopMin();
            options.bottomMax = getBottomMax();
            options.bottomMin = getBottomMin();
            options.dock = getDock().getCssName();
            options.orientation = getAxis().getCssName();
            splitted.touchSplit(options);
        }
    }

    /**
     * Get the Maximum left space.
     */
    public double getLeftMax() {
        return leftMax;
    }

    /**
     * Set the Maximum left space while dragging horizontally.
     */
    public void setLeftMax(double leftMax) {
        this.leftMax = leftMax;
    }

    /**
     * Get the Minimum left max space.
     */
    public double getLeftMin() {
        return leftMin;
    }

    /**
     * Set the Minimum left space while dragging horizontally.
     */
    public void setLeftMin(double leftMin) {
        this.leftMin = leftMin;
    }

    /**
     * Get the Maximum right space.
     */
    public double getRightMax() {
        return rightMax;
    }

    /**
     * Set the Maximum right space while dragging horizontally.
     */
    public void setRightMax(double rightMax) {
        this.rightMax = rightMax;
    }

    /**
     * Get the minimum right space.
     */
    public double getRightMin() {
        return rightMin;
    }

    /**
     * Set the minimum right space while dragging horizontally.
     */
    public void setRightMin(double rightMin) {
        this.rightMin = rightMin;
    }

    /**
     * Get the axis orientation of splitter component.
     */
    public Axis getAxis() {
        return axis;
    }

    /**
     * Set the axis orientation of splitter component (HORIZONTAL(Default) and VERTICAL).
     */
    public void setAxis(Axis axis) {
        this.axis = axis;
    }

    /**
     * Get the dock value.
     */
    public Dock getDock() {
        return dock;
    }

    /**
     * Set the dock value (LEFT, RIGHT -> HORIZONTAL AXIS and TOP,LEFT -> VERTICAL AXIS).
     */
    public void setDock(Dock dock) {
        this.dock = dock;
    }

    /**
     * Get the minimum top space.
     */
    public double getTopMin() {
        return topMin;
    }

    /**
     * Set the minimum top space while dragging vertically.
     */
    public void setTopMin(double topMin) {
        this.topMin = topMin;
    }

    /**
     * Get the maximum top space.
     */
    public double getTopMax() {
        return topMax;
    }

    /**
     * Set the maximum top space while dragging vertically.
     */
    public void setTopMax(double topMax) {
        this.topMax = topMax;
    }

    /**
     * Get the minimum bottom space.
     */
    public double getBottomMin() {
        return bottomMin;
    }

    /**
     * Set the minimum bottom space while dragging vertically.
     */
    public void setBottomMin(double bottomMin) {
        this.bottomMin = bottomMin;
    }

    /**
     * Get the maximum bottom space.
     */
    public double getBottomMax() {
        return bottomMax;
    }

    /**
     * Set the maximum bottom space while dragging vertically.
     */
    public void setBottomMax(double bottomMax) {
        this.bottomMax = bottomMax;
    }

    /**
     * Get the bar position in percent divided by 100.
     */
    public double getBarPosition() {
        return barPosition / 100;
    }

    /**
     * Set the bar position in percent.
     */
    public void setBarPosition(double barPosition) {
        this.barPosition = barPosition;
    }

    /**
     * Get the bar's thickness in px.
     */
    public double getThickness() {
        return thickness;
    }

    /**
     * Set the bar's thickness in px.
     */
    public void setThickness(double thickness) {
        this.thickness = thickness;
    }
}

==> gwt-material-addins-2.0.1.jar: gwt/material/design/addins/client/splitpanel/MaterialSplitPanel.java <==
/*
 * #%L
 * GwtMaterial
 * %%
 * Copyright (C) 2015 - 2017 GwtMaterialDesign
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */
package gwt.material.design.addins.client.splitpanel;

import com.google.gwt.core.client.GWT;
import com.google.gwt.dom.client.Document;
import gwt.material.design.addins.client.MaterialAddins;
import gwt.material.design.addins.client.splitpanel.constants.Dock;
import gwt.material.design.addins.client.splitpanel.constants.Side;
import gwt.material.design.addins.client.splitpanel.js.JsSplitPanelOptions;
import gwt.material.design.addins.client.splitpanel.js.TouchSplitter;
import gwt.material.design.client.MaterialDesignBase;
import gwt.material.design.client.base.JsLoader;
import gwt.material.design.client.base.MaterialWidget;
import gwt.material.design.client.constants.Axis;

import static gwt.material.design.addins.client.splitpanel.js.JsSplitPanel.$;

//@formatter:off

/**
 * A high performance content splitter compatible with touch events
 * <p>
 * <h3>XML Namespace Declaration</h3>
 * <pre>
 * {@code
 * xmlns:ma='urn:import:gwt.material.design.addins.client'
 * }
 * </pre>
 * <p>
 * <h3>UiBinder Usage:</h3>
 * <pre>
 * {@code
 *   <ma:splitpanel.MaterialSplitPanel height="500px">
 *       <m:MaterialPanel grid="l6 m6 s6" backgroundColor="grey lighten-2">
 *           <m:MaterialTitle textAlign="CENTER" title="Left Zone" description="Content must be added here"/>
 *       </m:MaterialPanel>
 *       <m:MaterialPanel grid="l6 m6 s6" backgroundColor="grey lighten-3">
 *           <m:MaterialTitle textAlign="CENTER" title="Right Zone" description="Content must be added here"/>
 *       </m:MaterialPanel>
 *   </ma:splitpanel.MaterialSplitPanel>
 * }
 * </pre>
 *
 * @author kevzlou7979
 * @see <a href="http://gwtmaterialdesign.github.io/gwt-material-demo/#splitpanel">Split Panel</a>
 * @see <a href="https://material.io/guidelines/layout/split-screen.html#split-screen-usage">Material Design Specification</a>
 * @see <a href="https://github.com/colelawrence/Touch-Splitter-jQuery">TouchSplitterJQuery 0.5.1</a>
 */
//@formatter:on
public class MaterialSplitPanel extends MaterialWidget implements JsLoader {

    static {
        if (MaterialAddins.isDebug()) {
            MaterialDesignBase.injectDebugJs(MaterialSplitPanelDebugClientBundle.INSTANCE.splitPanelDebugJs());
            MaterialDesignBase.injectCss(MaterialSplitPanelDebugClientBundle.INSTANCE.splitPanelDebugCss());
        } else {
            MaterialDesignBase.injectDebugJs(MaterialSplitPanelClientBundle.INSTANCE.splitPanelJs());
            MaterialDesignBase.injectCss(MaterialSplitPanelClientBundle.INSTANCE.splitPanelCss());
        }
    }

    private TouchSplitter touchSplitter;
    private JsSplitPanelOptions options = JsSplitPanelOptions.create();

    public MaterialSplitPanel() {
        super(Document.get().createDivElement());
    }

    @Override
    protected void onLoad() {
        super.onLoad();

        load();
    }

    @Override
    public void load() {
        options.dock = getDock().getCssName();
        options.orientation = getAxis().getCssName();
        touchSplitter = $(getElement()).touchSplit(options);
    }

    public TouchSplitter getTouchSplitter() {
        return touchSplitter;
    }

    @Override
    protected void onUnload() {
        super.onUnload();

        unload();
    }

    @Override
    public void unload() {
        destroy();
    }

    public void destroy() {
        destroy(Side.ALL);
    }

    public void destroy(Side side) {
        if (touchSplitter != null) {
            touchSplitter.destroy(side.getCssName());
        } else {
            GWT.log("Please initialize the touchsplitter.", new IllegalStateException());
        }
    }

    @Override
    public void reload() {
        unload();
        load();
    }

    /**
     * Get the bar position in percent divided by 100.
     */
    public double getBarPosition() {
        return options.barPosition;
    }

    /**
     * Set the bar position in percent.
     */
    public void setBarPosition(double barPosition) {
        options.barPosition = barPosition / 100;
    }

    /**
     * Get the bar's thickness in px.
     */
    public double getThickness() {
        return options.thickness != null ? Double.parseDouble(options.thickness.replace("px", "")) : null;
    }

    /**
     * Set the bar's thickness in px.
     */
    public void setThickness(double thickness) {
        options.thickness = thickness + "px";
    }

    /**
     * Get the Maximum left space.
     */
    public double getLeftMax() {
        return options.leftMax;
    }

    /**
     * Set the Maximum left space while dragging horizontally.
     */
    public void setLeftMax(double leftMax) {
        options.leftMax = leftMax;
    }

    /**
     * Get the Minimum left max space.
     */
    public double getLeftMin() {
        return options.leftMin;
    }

    /**
     * Set the Minimum left space while dragging horizontally.
     */
    public void setLeftMin(double leftMin) {
        options.leftMin = leftMin;
    }

    /**
     * Get the Maximum right space.
     */
    public double getRightMax() {
        return options.rightMax;
    }

    /**
     * Set the Maximum right space while dragging horizontally.
     */
    public void setRightMax(double rightMax) {
        options.rightMax = rightMax;
    }

    /**
     * Get the minimum right space.
     */
    public double getRightMin() {
        return options.rightMin;
    }

    /**
     * Set the minimum right space while dragging horizontally.
     */
    public void setRightMin(double rightMin) {
        options.rightMin = rightMin;
    }

    /**
     * Get the minimum top space.
     */
    public double getTopMin() {
        return options.topMin;
    }

    /**
     * Set the minimum top space while dragging vertically.
     */
    public void setTopMin(double topMin) {
        options.topMin = topMin;
    }

    /**
     * Get the maximum top space.
     */
    public double getTopMax() {
        return options.topMax;
    }

    /**
     * Set the maximum top space while dragging vertically.
     */
    public void setTopMax(double topMax) {
        options.topMax = topMax;
    }

    /**
     * Get the minimum bottom space.
     */
    public double getBottomMin() {
        return options.bottomMin;
    }

    /**
     * Set the minimum bottom space while dragging vertically.
     */
    public void setBottomMin(double bottomMin) {
        options.bottomMin = bottomMin;
    }

    /**
     * Get the maximum bottom space.
     */
    public double getBottomMax() {
        return options.bottomMax;
    }

    /**
     * Set the maximum bottom space while dragging vertically.
     */
    public void setBottomMax(double bottomMax) {
        options.bottomMax = bottomMax;
    }

    /**
     * Get the axis orientation of splitter component.
     */
    public Axis getAxis() {
        return options.orientation != null ? Axis.fromStyleName(options.orientation) : null;
    }

    /**
     * Set the axis orientation of splitter component (HORIZONTAL(Default) and VERTICAL).
     */
    public void setAxis(Axis axis) {
        options.orientation = axis.getCssName();
    }

    /**
     * Get the dock value.
     */
    public Dock getDock() {
        return options.dock != null ? Dock.fromStyleName(options.dock) : null;
    }

    /**
     * Set the dock value (LEFT, RIGHT -> HORIZONTAL AXIS and TOP,LEFT -> VERTICAL AXIS).
     */
    public void setDock(Dock dock) {
        options.dock = dock.getCssName();
    }
}
